@@ -1,7 +1,8 @@
 import os
+from typing import Callable, List
 
 
-def tfrq(func, params, num_cores=os.cpu_count()):
+def tfrq(func: Callable, params: List, num_cores=os.cpu_count()):
     import math
     from concurrent.futures import ProcessPoolExecutor
     """
@@ -12,6 +13,7 @@ def tfrq(func, params, num_cores=os.cpu_count()):
     Parameters:
         - func (function): The function to be executed in parallel.
         - params (List): The list of parameters to be passed to the function.
+        - num_cores: default is os.cpu_count() - an integer
 
     Returns:
         - results (List): A list of results of the function execution for each parameter.
